==> CSBS-VBS-Upgrade-Plugin-8.3.0.zip: CSBS/scripts/deploy/karbor/sub_job_register_silvan.py <==
import utils.common.log as logger
from utils.common.exception import HCCIException
from utils.common.message import Message

from plugins.CSBS.common.constant import KAEBOR_EXT_PORT
from plugins.CSBS.common.constant import RegisterToMOInfo
from plugins.CSBS.common.karbor import KarborUtil
from plugins.CSBS.common.params_tool import ParamTool
from plugins.CSBS.common.register_silvan import RegisterSilvan
from plugins.CSBS.common.step_base import DeployBaseSubJob

logger.init("CSBS")


class CSBSAndVBSRegisterSilvan(DeployBaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list=None):
        super(CSBSAndVBSRegisterSilvan, self).__init__(project_id, pod_id, regionid_list)
        self.project_id = project_id
        self.pod_id = pod_id
        self.csbs_id = "csbs"
        self.vbs_id = "vbs"
        self.param_tool = ParamTool(self.project_id, self.pod_id)
        self.register_silvan = RegisterSilvan()
        self.region_id = self.param_tool.get_region_id()
        self.console_domain_name = \
            self.param_tool.get_console_domain_name()
        self.register_info = RegisterToMOInfo(
            self.region_id, self.console_domain_name)
        self.karbor_util = KarborUtil(self.project_id, self.pod_id)

    def execute(self, project_id, pod_id, regionid_list=None):
        try:
            return self._register_silvan()
        except Exception as e:
            logger.error(str(e))
            return Message(500, HCCIException("640016", str(e)))

    def _register_silvan(self):
        if not self._register_endpoint():
            return Message(500, HCCIException("640017"))

        # Registering the association between regions and endpoints.
        csbs_float_ip = self.karbor_util.get_karbor_float_ip()
        result2_1 = self.register_silvan.register_region_and_endpoint_association(
            self.pod_id, self.region_id, self.csbs_id, csbs_float_ip, KAEBOR_EXT_PORT)
        if not result2_1:
            logger.error(f"Register {self.csbs_id} service of the association between region and endpoint failed.")
            return Message(500, HCCIException("640018"))

        result2_2 = self.register_silvan.register_region_and_endpoint_association(
            self.pod_id, self.region_id, self.vbs_id, csbs_float_ip, KAEBOR_EXT_PORT)
        if not result2_2:
            logger.error(f"Register {self.vbs_id} service of the association between region and endpoint failed.")
            return Message(500, HCCIException("640018"))

        # csbs apply links
        result3_1 = self.register_silvan.register_links_info(
            self.pod_id, "apply_url_csbs", self.csbs_id, "detail", self.register_info.csbs_apply_link, "product",
            region_id=self.region_id)
        if not result3_1:
            logger.error(f"Register {self.csbs_id} apply link failed.")
            return Message(500, HCCIException("640019"))
        # csbs detail links
        result3_2 = self.register_silvan.register_links_info(
            self.pod_id, "detail_url_csbs", self.csbs_id, "detail", self.register_info.csbs_detail_link, "product",
            region_id=self.region_id)
        if not result3_2:
            logger.error(f"Register {self.csbs_id} detail link failed.")
            return Message(500, HCCIException("640019"))

        # vbs apply links
        result3_3 = self.register_silvan.register_links_info(
            self.pod_id, "apply_url_vbs", self.vbs_id, "detail", self.register_info.vbs_apply_link, "product",
            region_id=self.region_id)
        if not result3_3:
            logger.error(f"Register {self.vbs_id} apply link failed.")
            return Message(500, HCCIException("640019"))
        # vbs detail links
        result3_4 = self.register_silvan.register_links_info(
            self.pod_id, "detail_url_vbs", self.vbs_id, "detail", self.register_info.vbs_detail_link, "product",
            region_id=self.region_id)
        if not result3_4:
            logger.error(f"Register {self.vbs_id} detail link failed.")
            return Message(500, HCCIException("640019"))

        is_succ, code = self._register_csbs_vbs_info()
        if not is_succ:
            return Message(500, HCCIException(code))
        return Message(200)

    def _register_csbs_vbs_info(self):
        # register_product_action
        for action in self.register_info.csbs_vbs_action_list:
            result4 = self.register_silvan.register_product_action(self.pod_id, action)
            if not result4:
                logger.error(f"Register product action failed, action info:{action}.")
                return False, "640021"

        # Register csbs product info.
        result4_1 = self.register_silvan.register_product_info(
            self.pod_id, self.region_id, self.csbs_id, self.register_info.csbs_product_info)
        if not result4_1:
            logger.error(f"Register {self.csbs_id} product info failed.")
            return False, "640020"

        # Register vbs product info.
        result4_2 = self.register_silvan.register_product_info(
            self.pod_id, self.region_id, self.vbs_id, self.register_info.vbs_product_info)
        if not result4_2:
            logger.error(f"Register {self.vbs_id} product info failed.")
            return False, "640020"

        # Register quota indicators.
        result5_1 = self.register_silvan.register_quota_indicators(
            self.pod_id, self.csbs_id, self.register_info.csbs_quota_indicators)
        if not result5_1:
            logger.error(f"Register {self.csbs_id} quota indicator info failed.")
            return False, "640088"
        result5_2 = self.register_silvan.register_quota_indicators(
            self.pod_id, self.vbs_id, self.register_info.vbs_quota_indicators)
        if not result5_2:
            logger.error(f"Register {self.vbs_id} quota indicator info failed.")
            return False, "640088"

        # Register csbs meter metrics.
        result6_1 = self.register_silvan.register_meter_metrics(self.pod_id, self.register_info.csbs_metric_info)
        if not result6_1:
            logger.error(f"Register {self.csbs_id} metric info failed.")
            return False, "640089"
        # Register vbs meter metrics.
        result6_2 = self.register_silvan.register_meter_metrics(self.pod_id, self.register_info.vbs_metric_info)
        if not result6_2:
            logger.error(f"Register {self.vbs_id} metric info failed.")
            return False, "640089"
        return True, ""

    def _register_endpoint(self):
        # Register csbs endpoint.
        # zh console
        result1_1 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.csbs_id, self.register_info.csbs_endpoint_info_zh, "zh")
        if not result1_1:
            logger.error(f"Register {self.csbs_id} endpoint failed.")
            return False
        # en console
        result1_2 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.csbs_id, self.register_info.csbs_endpoint_info_en, "en")
        if not result1_2:
            logger.error(f"Register {self.csbs_id} endpoint failed.")
            return False

        # Register vbs endpoint.
        # zh console
        result1_3 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.vbs_id, self.register_info.vbs_endpoint_info_zh, "zh")
        if not result1_3:
            logger.error(f"Register {self.vbs_id} endpoint failed.")
            return False
        # en console
        result1_4 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.vbs_id, self.register_info.vbs_endpoint_info_en, "en")
        if not result1_4:
            logger.error(f"Register {self.vbs_id} endpoint failed.")
            return False
        return True

==> CSBS-VBS-Upgrade-Plugin-8.5.0.zip: CSBS/scripts/deploy/karbor/sub_job_register_silvan.py <==
import utils.common.log as logger
from utils.common.exception import HCCIException
from utils.common.message import Message

from plugins.CSBS.common.constant import KAEBOR_EXT_PORT
from plugins.CSBS.common.constant import RegisterToMOInfo
from plugins.CSBS.common.karbor import KarborUtil
from plugins.CSBS.common.params_tool import ParamTool
from plugins.CSBS.common.register_silvan import RegisterSilvan
from plugins.CSBS.common.step_base import DeployBaseSubJob

logger.init("CSBS")


class CSBSAndVBSRegisterSilvan(DeployBaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list=None):
        super(CSBSAndVBSRegisterSilvan, self).__init__(project_id, pod_id, regionid_list)
        self.project_id = project_id
        self.pod_id = pod_id
        self.csbs_id = "csbs"
        self.vbs_id = "vbs"
        self.param_tool = ParamTool(self.project_id, self.pod_id)
        self.register_silvan = RegisterSilvan()
        self.region_id = self.param_tool.get_region_id()
        self.console_domain_name = \
            self.param_tool.get_console_domain_name()
        self.register_info = RegisterToMOInfo(
            self.region_id, self.console_domain_name)
        self.karbor_util = KarborUtil(self.project_id, self.pod_id)

    def execute(self, project_id, pod_id, regionid_list=None):
        try:
            return self._register_silvan()
        except Exception as err:
            logger.error(str(err))
            return Message(500, HCCIException("640016", str(err)))

    def _register_silvan(self):
        if not self._register_endpoint():
            return Message(500, HCCIException("640017"))

        # Registering the association between regions and endpoints.
        csbs_float_ip = self.karbor_util.get_karbor_float_ip()
        result2_1 = self.register_silvan.register_region_and_endpoint_association(
            self.pod_id, self.region_id, self.csbs_id, csbs_float_ip, KAEBOR_EXT_PORT)
        if not result2_1:
            logger.error(f"Register {self.csbs_id} service of the association between region and endpoint failed.")
            return Message(500, HCCIException("640018"))

        result2_2 = self.register_silvan.register_region_and_endpoint_association(
            self.pod_id, self.region_id, self.vbs_id, csbs_float_ip, KAEBOR_EXT_PORT)
        if not result2_2:
            logger.error(f"Register {self.vbs_id} service of the association between region and endpoint failed.")
            return Message(500, HCCIException("640018"))

        # csbs apply links
        result3_1 = self.register_silvan.register_links_info(
            self.pod_id, "apply_url_csbs", self.csbs_id, "detail", self.register_info.csbs_apply_link, "product",
            region_id=self.region_id)
        if not result3_1:
            logger.error(f"Register {self.csbs_id} apply link failed.")
            return Message(500, HCCIException("640019"))
        # csbs detail links
        result3_2 = self.register_silvan.register_links_info(
            self.pod_id, "detail_url_csbs", self.csbs_id, "detail", self.register_info.csbs_detail_link, "product",
            region_id=self.region_id)
        if not result3_2:
            logger.error(f"Register {self.csbs_id} detail link failed.")
            return Message(500, HCCIException("640019"))

        # vbs apply links
        result3_3 = self.register_silvan.register_links_info(
            self.pod_id, "apply_url_vbs", self.vbs_id, "detail", self.register_info.vbs_apply_link, "product",
            region_id=self.region_id)
        if not result3_3:
            logger.error(f"Register {self.vbs_id} apply link failed.")
            return Message(500, HCCIException("640019"))
        # vbs detail links
        result3_4 = self.register_silvan.register_links_info(
            self.pod_id, "detail_url_vbs", self.vbs_id, "detail", self.register_info.vbs_detail_link, "product",
            region_id=self.region_id)
        if not result3_4:
            logger.error(f"Register {self.vbs_id} detail link failed.")
            return Message(500, HCCIException("640019"))

        is_succ, code = self._register_csbs_vbs_info()
        if not is_succ:
            return Message(500, HCCIException(code))
        return Message(200)

    def _register_csbs_vbs_info(self):
        # register_product_action
        for action in self.register_info.csbs_vbs_action_list:
            result4 = self.register_silvan.register_product_action(self.pod_id, action)
            if not result4:
                logger.error(f"Register product action failed, action info:{action}.")
                return False, "640021"

        # Register csbs product info.
        result4_1 = self.register_silvan.register_product_info(
            self.pod_id, self.region_id, self.csbs_id, self.register_info.csbs_product_info)
        if not result4_1:
            logger.error(f"Register {self.csbs_id} product info failed.")
            return False, "640020"

        # Register vbs product info.
        result4_2 = self.register_silvan.register_product_info(
            self.pod_id, self.region_id, self.vbs_id, self.register_info.vbs_product_info)
        if not result4_2:
            logger.error(f"Register {self.vbs_id} product info failed.")
            return False, "640020"

        # Register quota indicators.
        result5_1 = self.register_silvan.register_quota_indicators(
            self.pod_id, self.csbs_id, self.register_info.csbs_quota_indicators)
        if not result5_1:
            logger.error(f"Register {self.csbs_id} quota indicator info failed.")
            return False, "640088"
        result5_2 = self.register_silvan.register_quota_indicators(
            self.pod_id, self.vbs_id, self.register_info.vbs_quota_indicators)
        if not result5_2:
            logger.error(f"Register {self.vbs_id} quota indicator info failed.")
            return False, "640088"

        # Register csbs meter metrics.
        result6_1 = self.register_silvan.register_meter_metrics(self.pod_id, self.register_info.csbs_metric_info)
        if not result6_1:
            logger.error(f"Register {self.csbs_id} metric info failed.")
            return False, "640089"
        # Register vbs meter metrics.
        result6_2 = self.register_silvan.register_meter_metrics(self.pod_id, self.register_info.vbs_metric_info)
        if not result6_2:
            logger.error(f"Register {self.vbs_id} metric info failed.")
            return False, "640089"
        return True, ""

    def _register_endpoint(self):
        # Register csbs endpoint.
        # zh console
        result1_1 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.csbs_id, self.register_info.csbs_endpoint_info_zh, "zh")
        if not result1_1:
            logger.error(f"Register {self.csbs_id} endpoint failed.")
            return False
        # en console
        result1_2 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.csbs_id, self.register_info.csbs_endpoint_info_en, "en")
        if not result1_2:
            logger.error(f"Register {self.csbs_id} endpoint failed.")
            return False

        # Register vbs endpoint.
        # zh console
        result1_3 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.vbs_id, self.register_info.vbs_endpoint_info_zh, "zh")
        if not result1_3:
            logger.error(f"Register {self.vbs_id} endpoint failed.")
            return False
        # en console
        result1_4 = self.register_silvan.register_endpoint(
            self.pod_id, self.region_id, self.vbs_id, self.register_info.vbs_endpoint_info_en, "en")
        if not result1_4:
            logger.error(f"Register {self.vbs_id} endpoint failed.")
            return False
        return True
